@@ -1,4 +1,4 @@
-__version__ = "1.0.13"
+__version__ = "1.0.15"
 
 from .resolvers.default_resolver import DefaultResolver
 from .resolvers.resolver import Resolver
@@ -7,6 +7,6 @@ from .resolvers.collection_resolvers.collection_resolver import CollectionResolv
 from .resolvers.processors.processor import Processor
 
 from .functional.load import from_string, from_file_uri, from_cli
-from .functional.util import merge, mask_in, mask_out
+from .functional.util import merge, mask_in, mask_out, apply
 from .functional.dotlist import from_dotlist, to_dotlist
 from .functional.convert import from_primitive, to_primitive
\ No newline at end of file
