@@ -1,3 +1,8 @@
+def _source_id_str(source_id):
+    if source_id is None:
+        return ""
+    return f" of source '{source_id}'"
+
 def unexpected_type_error(expected_type_or_types, actual_value):
     if isinstance(expected_type_or_types, list):
         expected_type_str = str(list(map(lambda t: t.__name__, expected_type_or_types)))
@@ -43,8 +48,9 @@ def missing_value_error(full_accessor):
 class InvalidAccessorError(Exception):
     pass
 
-def invalid_accessor_error(accessor_until_invalid, full_accessor):
-    return InvalidAccessorError(f"invalid accessor '{accessor_until_invalid}' within '{full_accessor}'")
+def invalid_accessor_error(accessor_until_invalid, trace_str, source_id=None):
+    return InvalidAccessorError(f"invalid accessor '{accessor_until_invalid}' in node '{trace_str}'"
+                                f"{_source_id_str(source_id)}")
 
 def empty_parameter_error(args_and_value_str):
     return ValueError(f"empty parameter in '{args_and_value_str}'")
@@ -52,9 +58,10 @@ def empty_parameter_error(args_and_value_str):
 def missing_parameter_error(args_and_value_str, n_args):
     return ValueError(f"missing parameter in '{args_and_value_str}', expected {n_args} parameters")
 
-def invalid_resolver_key(resolver_key, valid_keys):
+def invalid_resolver_key(resolver_key, valid_keys, trace_str, source_id):
     # don't use key error here as it escapes the whole string and the ' characters
-    return ValueError(f"invalid resolver key '{resolver_key}' valid keys are: {valid_keys}")
+    return ValueError(f"invalid resolver key '{resolver_key}' in node '{trace_str}' (valid keys are: {valid_keys})"
+                      f"{_source_id_str(source_id)}")
 
 def empty_result():
     return MissingValueError("empty result")
@@ -63,4 +70,15 @@ def incompatible_type(type1, type2):
     return TypeError(f"type '{type1}' is incompatible with '{type2}'")
 
 def list_merge_invalid_resolving_strategy(key):
-    return ValueError(f"merging two lists requires valid resolving strategy (key='{key}')")
\ No newline at end of file
+    return ValueError(f"merging two lists requires valid resolving strategy (key='{key}')")
+
+def template_path_has_to_be_set(template_key, valid_templates):
+    return ValueError(f"invalid template key '{template_key}' (no template path set and template key is not in "
+                      f"{str(valid_templates)})")
+
+def template_file_doesnt_exist(file_uri):
+    return FileNotFoundError(f"template file '{file_uri}' doesn't exist")
+
+def invalid_evaluate_expression(expression, error, trace_str, source_id):
+    return ValueError(f"invalid eval expression '{expression}' (raised {type(error).__name__}: {str(error)}) in node "
+                      f"'{trace_str}'{_source_id_str(source_id)}")
\ No newline at end of file
