@@ -46,7 +46,7 @@ class TemplateResolver(CollectionResolver):
                     #   template: ${yaml:some_template.yaml}
                     #   template.vars:
                     #     param: 5
-                    resolved_scalar = self.nested_yaml_resolver.resolve_scalar(template, root_node=root_node)
+                    resolved_scalar = self.nested_yaml_resolver.resolve_scalar(template, root_node=root_node, trace=trace)
                     # merge template parameters into template
                     template_params_keys = list(filter(lambda key: key.startswith("template."), node.keys()))
                     template_params = mask_in(node, template_params_keys)
@@ -54,9 +54,8 @@ class TemplateResolver(CollectionResolver):
                     resolved_template_params = {}
                     for k, v in template_params.items():
                         new_key = k.replace("template.", "")
-                        if isinstance(v, KCScalar):
-                            v = root_resolver.resolve(v, root_node=root_node)
-                            v = from_primitive(v)
+                        v = root_resolver.resolve(v, root_node=root_node)
+                        v = from_primitive(v)
                         resolved_template_params[new_key] = v
 
                     kc_resolved_scalar = from_primitive(resolved_scalar)
