@@ -8,8 +8,8 @@ class SelectResolver(ScalarResolver):
     e.g. model: ${select:base:${yaml:models/vit}}
     """
 
-    def resolve(self, args_and_value, **_):
+    def resolve(self, args_and_value, root_node, trace, **_):
         args, value = parse_resolver_args_and_value(args_and_value, n_args=1)
         accessors = string_to_accessors(args[0])
-        node = select(root_node=value, accessors=accessors)
+        node = select(root_node=value, accessors=accessors, trace=trace, source_id=root_node.source_id)
         return node
\ No newline at end of file
